@@ -23,7 +23,7 @@ class visualizer(object):
     def filled_polygon(self, zonoset, face_color, alpha=.1):
         x=zonoset[0]
         y=zonoset[1]
-        plt.fill(x, y, facecolor=face_color, edgecolor='k', linewidth=3, alpha=alpha)
+        plt.fill(x, y, facecolor=face_color, edgecolor='k', linewidth=.0003, alpha=alpha)
 
     def show_traj(self, points):
         cmap = self.get_colormap("plasma")
